==> hybridstart-1.1.5.tgz: package/README.md <==

# HybridStart

基于[apicloud](http://www.apicloud.com/)的混合应用开发框架，可能是开发这一类混合应用的最佳实践。

[![npm](https://img.shields.io/npm/v/hybridstart.svg)](https://www.npmjs.com/package/hybridstart/) [![GitHub release](https://img.shields.io/github/release/tower1229/HybridStart.svg)]() [![license](https://img.shields.io/github/license/tower1229/HybridStart.svg)]()

## 提供
- 完全独立可剥离的UI，便于风格定制
- 清晰的开发模式，做APP从未这么简单
- 井然有序的代码组织，页面再多也不乱
- 熟悉的模块化开发体验，用了就回不去了
- 丰富的示例，助你快速上手

## 快速开始 
- 在apicloud平台创建项目，将代码检出到本地，然后清空所有文件
- 将[Hybrid Start项目](https://github.com/tower1229/HybridStart.git)除"/docs"以外文件拷贝进项目文件夹
- 修改`config.xml`中appid
- 提交代码，平台打包安装

## 文档 
[HybridStart Documention](http://refined-x.com/HybridStart/docs/)

[HybridStart专题文章](http://refined-x.com/tags/HybridStart/)

## 下载

项目主页：http://refined-x.com/HybridStart/

git：`git clone https://github.com/tower1229/HybridStart.git`

npm：`npm i hybridstart`


## 默认集成插件
- [UIPullRefreshFlash](http://docs.apicloud.com/Client-API/UI-Layout/UIPullRefreshFlash)自定义下拉刷新
- [ajpush](http://docs.apicloud.com/Client-API/Open-SDK/ajpush)极光推送
- [bMap](http://docs.apicloud.com/Client-API/Open-SDK/bMap)百度地图
- [mam](http://docs.apicloud.com/Client-API/Cloud-Service/mam)版本管理必备
- [zip](https://docs.apicloud.com/Client-API/Func-Ext/zip)扩展插件解压

## 资源
[体验APP](http://app.mi.com/details?id=com.apicloud.A6997660453388)

[代码仓库](https://github.com/tower1229/HybridStart)

[源码下载](https://github.com/tower1229/HybridStart/archive/master.zip)

## 更多
> [前端路上](http://refined-x.com)

<br /><br />

==> hybridstart-1.2.3.tgz: package/README.md <==

# HybridStart

基于[apicloud](http://www.apicloud.com/)的混合应用开发框架，可能是开发这一类混合应用的最佳实践。

[![npm](https://img.shields.io/npm/v/hybridstart.svg)](https://www.npmjs.com/package/hybridstart/) [![GitHub release](https://img.shields.io/github/release/tower1229/HybridStart.svg)]() [![license](https://img.shields.io/github/license/tower1229/HybridStart.svg)]()

## 提供
- 完全独立可剥离的UI，便于风格定制
- 清晰的开发模式，做APP从未这么简单
- 井然有序的代码组织，页面再多也不乱
- 熟悉的模块化开发体验，用了就回不去了
- 丰富的示例，助你快速上手

## 快速开始 
- 在在APICloud平台创建新项目，添加[默认集成插件](#默认集成插件)
- 将代码检出到本地，备份config.xml中的`appid`信息并清空所有文件
- 将[Hybrid Start项目](https://github.com/tower1229/HybridStart.git)除"/docs"以外文件拷贝进项目文件夹，修改新config.xml里的`appid`
- 提交代码，平台打包

## 默认集成插件
- [UIPullRefreshFlash](http://docs.apicloud.com/Client-API/UI-Layout/UIPullRefreshFlash)自定义下拉刷新
- [ajpush](http://docs.apicloud.com/Client-API/Open-SDK/ajpush)极光推送
- [bMap](http://docs.apicloud.com/Client-API/Open-SDK/bMap)百度地图
- [mam](http://docs.apicloud.com/Client-API/Cloud-Service/mam)版本管理必备
- [zip](https://docs.apicloud.com/Client-API/Func-Ext/zip)扩展插件解压

## 文档 
[HybridStart Documention](http://refined-x.com/HybridStart/docs/)

[HybridStart专题文章](http://refined-x.com/tags/HybridStart/)

## 课程

[《Hybrid App 开发快速指南》](https://gitbook.cn/gitchat/column/5b679a1d201ffa4ab88e7d5d)

## 下载

项目主页：http://refined-x.com/HybridStart/

git：`git clone https://github.com/tower1229/HybridStart.git`

npm：`npm i hybridstart`

## 资源
[体验APP](http://app.mi.com/details?id=com.apicloud.A6997660453388)

[代码仓库](https://github.com/tower1229/HybridStart)

[源码下载](https://github.com/tower1229/HybridStart/archive/master.zip)

## 更多
> [前端路上](http://refined-x.com)

<br /><br />
